static void usage()
{
	xconf_error (MSG_U(T_USAGE
		,"linuxconf --modulemain MODULEN usage\n"
		 "\n"
		 "    MODULEN --option ...\n")
		);
}

PUBLIC void MODULE_MODULEN::usage (SSTRINGS &tb)
{
	tb.add (new SSTRING (MSG_R(T_USAGE)));
}

PUBLIC int MODULE_MODULEN::execmain (int argc , char *argv[], bool standalone)
{
	int ret = LNCF_NOT_APPLICABLE;
	const char *pt = strrchr(argv[0],'/');
	if (pt != NULL){
		pt++;
	}else{
		pt = argv[0];
	}
	if (strcmp(pt,"MODULEN")==0){
		ret = -1;
		if (argc == 1){
			CONTEXT_LOCK l("MODULEN");
			if (l.isok()){
				// ### Place call to main menu of the module
			}
		}else{
			// ### Add some option parsing for the module
			::usage();
		}
	}
	return ret;
}

